Function xt::translate

source · []
pub fn translate<W>(
    input: Handle<'_>,
    from: Option<Format>,
    to: Format,
    output: W
) -> Result<(), Box<dyn Error>> where
    W: Write
Translates a single serialized input to serialized output in a different format.

When from is None, xt will attempt to detect the input format using an unspecified and unstable algorithm.